@@ -6,12 +6,15 @@
 import time
 
 import board
+from keypad import Keys
 
 from button_handler import ButtonHandler
 
-button = ButtonHandler(board.D9)
+scanner = Keys([board.D9], value_when_pressed=False)
+button_handler = ButtonHandler(scanner.events, set())
 
 while True:
-    button.update()
-    print(button.is_pressed)
+    inputs = button_handler.update()
+    for input_ in inputs:
+        print(input_)
     time.sleep(0.01)
